@@ -5,7 +5,7 @@ use warnings;
 use vars qw($VERSION);
 use 5.008;
 
-$VERSION = '1.11';
+$VERSION = '1.12';
 
 =begin markdown
 
@@ -21,7 +21,7 @@ Business::Tax::VAT - perform European VAT calculations
 
 =head1 VERSION
 
-This pod describes version 1.11
+This pod describes version 1.12
 
 =head1 SYNOPSIS
 
@@ -67,7 +67,7 @@ sub _item {
 package Business::Tax::VAT::Price;
 
 use vars qw($VERSION);
-$VERSION = '1.11';
+$VERSION = '1.12';
 
 our %RATE;
 
@@ -86,7 +86,7 @@ sub _calculate_vat_rates {
         es => 21, #spain
         fi => 24, #finland
         fr => 20, #france
-        gr => 23, #greece
+        gr => 24, #greece
         hr => 25, #crotia
         hu => 27, #hungary
         ie => 23, #ireland
@@ -98,7 +98,7 @@ sub _calculate_vat_rates {
         nl => 21, #netherlands
         pl => 23, #poland
         pt => 23, #portugal
-        ro => 24, #romania
+        ro => 19, #romania
         se => 25, #sweden
         si => 22, #slovenia
         sk => 20, #slovakia
@@ -205,27 +205,30 @@ This module uses the following rates and codes:
 
   at, Austria, 20%
   be, Belgium, 21%
-  cy, Cyprus, 15%
-  cz, Czech Republic, 19%
+  bg, Bulgaria 20%
+  hr, Croatia 25%
+  cy, Cyprus, 19%
+  cz, Czech Republic, 21%
   dk, Denmark, 25%
-  ee, Estonia, 18%
-  fi, Finland, 22%
-  fr, France, 19.6%
+  ee, Estonia, 20%
+  fi, Finland, 24%
+  fr, France, 20%
   de, Germany, 19%
-  gr, Greece, 17.5%
-  hu, Hungary, 25%
-  ie, Ireland, 21%
+  gr, Greece, 24%
+  hu, Hungary, 27%
+  ie, Ireland, 23%
   it, Italy, 22%
-  lv, Latvia, 18%
-  lt, Lithuania, 17.5%
+  lv, Latvia, 21%
+  lt, Lithuania, 21%
   lu, Luxembourg, 17%
   mt, Malta, 18%
-  nl, The Netherlands, 19%
-  pl, Poland, 22%
-  pt, Portugal, 21%
-  sk, Slovak Republic, 19%
-  si, Slovenia, 20%
-  es, Spain, 16%
+  nl, The Netherlands, 21%
+  pl, Poland, 23%
+  pt, Portugal, 23%
+  ro, Romania 19%
+  sk, Slovak Republic, 20%
+  si, Slovenia, 22%
+  es, Spain, 21%
   se, Sweden, 25%
 
 If any of these rates become incorrect, or if you wish to use
@@ -236,7 +239,7 @@ VAT in Austria), then you can (locally) set the rate by assigning to
   local $Business::Tax::VAT::Price::RATE{at} = 0
     if ($product_type eq 'book' and $country eq 'at');
 
-=head1 DYNAMICAALY ADDING A COUNTRY
+=head1 DYNAMICALLY ADDING A COUNTRY
 
 If you want to add your own country, do the following:
 
@@ -250,18 +253,31 @@ If you want to add your own country, do the following:
 
 =over
 
-=item * L<http://www.vatlive.com/> current and historic VAT rates resource
+=item * L<European Commission Taxes database, search engine|https://ec.europa.eu/taxation_customs/tedb/splSearchForm.html>
+
+=item * L<Resource for current and historic VAT rates|http://www.vatlive.com/>
 
 =back
 
 =head1 AUTHOR
 
-Tony Bowden
+=over
+
+=item * Tony Bowden
+
+=item * Jonas B. (jonasbn), current maintainer
+
+=back
 
 =head1 BUGS and QUERIES
 
-Please direct all correspondence regarding this module to:
-  bug-Business-Tax-VAT@rt.cpan.org
+Please direct all correspondence regarding this distribution to:
+
+=over
+
+=item * L<GitHub|https://github.com/jonasbn/Business-Tax-VAT/issues>
+
+=back
 
 =head1 ACKNOWLEDGEMENTS
 
